@@ -5,16 +5,14 @@ import os
 import re
 import shutil
 from datetime import datetime
-from logging import DEBUG
 from pathlib import Path, PurePosixPath
 from subprocess import Popen, PIPE, STDOUT
 
 from celery import Celery
 
 from render import RENDER_DIR, LOG_DIR
-import render.aws as aws
 from render.logger import configure_logger
-from render.util import user_data
+from render.s3 import S3, AWS_S3
 
 celery = Celery()
 celery.config_from_object('render.celeryconfig')
@@ -117,7 +115,7 @@ class Scene:
 
 
 class Render:
-    def __init__(self, scene: Scene, client: aws.S3):
+    def __init__(self, scene: Scene, client: S3):
         self.scene = scene
         self.client = client
 
@@ -165,7 +163,7 @@ def record_time(f):
     return wrapper
 
 
-def collect_logs(scene: Scene, client: aws.S3):
+def collect_logs(scene: Scene, client: S3):
     logger.info("Collecting log files...")
     for file in itertools.chain(
             # additional logs could be appended here
@@ -181,19 +179,11 @@ def collect_logs(scene: Scene, client: aws.S3):
 
 def run(scene_key):
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
-    assert user_data['aws_access_key_id'], "aws_access_key_id must be defined"
-    assert user_data['aws_secret_access_key'], "aws_secret_access_key must be defined"
-    assert user_data['aws_endpoint'], "aws_endpoint must be defined"
-    assert user_data['aws_bucket'], "aws_bucket must be defined"
-    s3 = aws.S3(
-        user_data['aws_bucket'],
-        aws_access_key_id=user_data['aws_access_key_id'],
-        aws_secret_access_key=user_data['aws_secret_access_key'],
-        endpoint_url=user_data['aws_endpoint'],
-    )
+
+    s3 = AWS_S3()
     scene = Scene(scene_key)
     # configure current logger for the specific scene
-    configure_logger(scene.workdir, level=logging.getLevelName(DEBUG))
+    configure_logger(scene.workdir / 'task.log')
 
     render = Render(scene, client=s3)
     try:
